@@ -1,8 +1,8 @@
 from prices import Price, PriceRange
 from unittest import TestCase
 
-from . import (InsufficientStock, Item, ItemLine, ItemRange, Partitioner,
-               ItemList, StockedItem)
+from . import (ClassifyingPartitioner, InsufficientStock, Item, ItemLine,
+               ItemList, ItemRange, Partitioner, StockedItem, partition)
 
 
 class Swallow(Item):
@@ -59,6 +59,14 @@ class LimitedShrubbery(StockedItem):
         return 1
 
 
+class SwallowPartitioner(ClassifyingPartitioner):
+
+    def classify(self, item):
+        if isinstance(item, Swallow):
+            return 'swallow'
+        return 'unknown'
+
+
 class ItemTest(TestCase):
 
     def test_get_price(self):
@@ -126,6 +134,48 @@ class PartitionerTest(TestCase):
         partitioner = Partitioner(item_set)
         self.assertTrue(partitioner)
 
+    def test_repr(self):
+        'Partitioner.__repr__() returns valid code'
+        partitioner = Partitioner([1])
+        self.assertEqual(partitioner.__repr__(), 'Partitioner([1])')
+
+
+class ClassifyingPartitionerTest(TestCase):
+
+    def test_classification(self):
+        'Partitions should be split according to the classifying key'
+        swallow = Swallow()
+        inquisition = SpanishInquisition()
+        cow = FetchezLaVache()
+        fake_cart = [inquisition, swallow, cow]
+        partitioner = SwallowPartitioner(fake_cart)
+        self.assertEqual(list(partitioner),
+                         [ItemList([swallow]),
+                          ItemList([inquisition, cow])])
+
+
+class PartitionTest(TestCase):
+
+    def test_basic_classification(self):
+        def keyfunc(item):
+            if item > 5:
+                return 'more'
+            return 'less'
+        partitioner = partition([1, 2, 3, 4, 5, 6, 7, 8, 9, 10], keyfunc)
+        self.assertEqual(list(partitioner),
+                         [ItemList([1, 2, 3, 4, 5]),
+                          ItemList([6, 7, 8, 9, 10])])
+
+    def test_custom_class(self):
+        def keyfunc(item):
+            if item > 5:
+                return 'more'
+            return 'less'
+        partitioner = partition([1, 2, 3, 4, 5, 6, 7, 8, 9, 10], keyfunc,
+                                partition_class=list)
+        self.assertEqual(list(partitioner),
+                         [[1, 2, 3, 4, 5], [6, 7, 8, 9, 10]])
+
 
 class StockedItemTest(TestCase):
 
